# ***Atlantis***
***Atlantis*** is a Python library for simplifying programming with Python for data science.

# Installation
You can just use pip to install Atlantis:

`pip install atlantis`

# Modules

- [***collections***](about_collections.md) helps with working with collections.
- [***colour***](about_colour.md) simplifies using colours.
- [***ds (datascience)***](about_ds.md) provides tools for:
  - data wrangling, 
  - validation, 
  - tuning,
  - sampling, 
  - evaluation,
  - clustering, and 
  - parallel processing of machine learning models.
- [***functions***](about_functions.md) manages higher order functions.
- [***hash***](about_hash.md) simplifies and standardizes hashing.
- [***text***](about_text.md) makes working with texts and strings easy.
- [***time***](about_time.md) 
  - provides methods for interacting with time and date as well as 
  - progress bars